@@ -46,9 +46,6 @@ static int is_file(const char *filename);
 static void add_font_path(GenerateOptions *gop, XConfigPtr config);
 static void add_modules(GenerateOptions *gop, XConfigPtr config);
 
-static XConfigDevicePtr add_device(XConfigPtr config, int bus, int domain,
-                                   int slot, char *boardname, int count);
-
 static void add_layout(GenerateOptions *gop, XConfigPtr config);
 
 static void add_inputref(XConfigPtr config, XConfigLayoutPtr layout,
@@ -95,14 +92,17 @@ XConfigPtr xconfigGenerate(GenerateOptions *gop)
 
 XConfigScreenPtr xconfigGenerateAddScreen(XConfigPtr config,
                                           int bus, int domain, int slot,
-                                          char *boardname, int count)
+                                          char *boardname, int count,
+                                          const char *driver,
+                                          const char *vendor)
 {
     XConfigScreenPtr screen, s;
     XConfigDevicePtr device;
     XConfigMonitorPtr monitor;
 
     monitor = xconfigAddMonitor(config, count);
-    device = add_device(config, bus, domain, slot, boardname, count);
+    device = add_device(config, bus, domain, slot, boardname, count,
+                        driver, vendor);
 
     screen = xconfigAlloc(sizeof(XConfigScreenRec));
 
@@ -426,16 +426,6 @@ XConfigMonitorPtr xconfigAddMonitor(XConfigPtr config, int count)
     monitor->vendor = xconfigStrdup("Unknown");  /* XXX */
     monitor->modelname = xconfigStrdup("Unknown"); /* XXX */
 
-    /* XXX check EDID for freq ranges */
-
-    monitor->n_hsync = 1;
-    monitor->hsync[0].lo = 28.0;
-    monitor->hsync[0].hi = 33.0;
-
-    monitor->n_vrefresh = 1;
-    monitor->vrefresh[0].lo = 43.0;
-    monitor->vrefresh[0].hi = 72.0;
-
     monitor->options = NULL;
     xconfigAddNewOption(&monitor->options, "DPMS", NULL);
 
@@ -458,8 +448,9 @@ XConfigMonitorPtr xconfigAddMonitor(XConfigPtr config, int count)
  * add_device()
  */
 
-static XConfigDevicePtr add_device(XConfigPtr config, int bus, int domain,
-                                   int slot, char *boardname, int count)
+XConfigDevicePtr add_device(XConfigPtr config, int bus, int domain,
+                            int slot, char *boardname, int count,
+                            const char *driver, const char *vendor)
 {
     XConfigDevicePtr device, d;
 
@@ -467,8 +458,9 @@ static XConfigDevicePtr add_device(XConfigPtr config, int bus, int domain,
 
     device->identifier = xconfigAlloc(32);
     snprintf(device->identifier, 32, DEVICE_IDENTIFIER, count);
-    device->driver = xconfigStrdup("nvidia");
-    device->vendor = xconfigStrdup("NVIDIA Corporation");
+    device->index_id = count;
+    device->driver = xconfigStrdup(driver);
+    device->vendor = xconfigStrdup(vendor);
 
     if (bus != -1 && domain != -1 && slot != -1) {
         device->busid = xconfigAlloc(32);
@@ -527,7 +519,8 @@ static void add_layout(GenerateOptions *gop, XConfigPtr config)
 
     /* assume 1 X screen */
 
-    screen = xconfigGenerateAddScreen(config, -1, -1, -1, NULL, 0);
+    screen = xconfigGenerateAddScreen(config, -1, -1, -1, NULL, 0,
+                                      "nvidia", "NVIDIA Corporation");
 
     /* create layout */
 
@@ -1240,11 +1233,7 @@ int xconfigAddKeyboard(GenerateOptions *gop, XConfigPtr config)
 #if defined(NV_SUNOS) || defined(NV_BSD)
         input->driver = xconfigStrdup("keyboard");
 #else
-        if (gop->xserver == X_IS_XORG) {
-            input->driver = xconfigStrdup("kbd");
-        } else {
-            input->driver = xconfigStrdup("keyboard");
-        }
+        input->driver = xconfigStrdup("kbd");
 #endif
     }
 
@@ -1313,15 +1302,13 @@ static char *xconfigGetDefaultProjectRoot(void)
  * get_xserver_information() - parse the versionString (from `X
  * -version`) and assign relevant information that we infer from the X
  * server version.
- *
- * Note: this implementation should be shared with nvidia-installer
  */
 
 static int get_xserver_information(const char *versionString,
-                                   int *isXorg,
-                                   int *isModular,
                                    int *autoloadsGLX,
-                                   int *supportsExtensionSection)
+                                   int *supportsExtensionSection,
+                                   int *xineramaPlusCompositeWorks,
+                                   const char **compositeExtensionName)
 {
 #define XSERVER_VERSION_FORMAT_1 "X Window System Version"
 #define XSERVER_VERSION_FORMAT_2 "X.Org X Server"
@@ -1332,17 +1319,10 @@ static int get_xserver_information(const char *versionString,
     /* check if this is an XFree86 X server */
 
     if (strstr(versionString, "XFree86 Version")) {
-        *isXorg = FALSE;
-        *isModular = FALSE;
-        *autoloadsGLX = FALSE;
-        *supportsExtensionSection = FALSE;
-        return TRUE;
+        xconfigErrorMsg(WarnMsg, "XFree86 is not supported.");
+        return FALSE;
     }
 
-    /* this must be an X.Org X server */
-
-    *isXorg = TRUE;
-
     /* attempt to parse the major.minor version out of the string */
 
     found = FALSE;
@@ -1362,17 +1342,6 @@ static int get_xserver_information(const char *versionString,
 
     if (!found) return FALSE;
 
-    /*
-     * isModular: X.Org X11R6.x X servers are monolithic, all others
-     * are modular
-     */
-
-    if (major == 6) {
-        *isModular = FALSE;
-    } else {
-        *isModular = TRUE;
-    }
-
     /*
      * supportsExtensionSection: support for the "Extension" xorg.conf
      * section was added between X.Org 6.7 and 6.8.  To account for
@@ -1400,6 +1369,29 @@ static int get_xserver_information(const char *versionString,
         *autoloadsGLX = TRUE;
     }
 
+    /*
+     * support for Xinerama and Composite at the same time works on X.Org
+     * xserver 1.15.
+     */
+
+    if ((major == 6) || (major == 7) || ((major == 1) && (minor < 15))) {
+        *xineramaPlusCompositeWorks = FALSE;
+    } else {
+        *xineramaPlusCompositeWorks = TRUE;
+    }
+    
+    /*
+     * With X.Org xserver version 1.20, the name of the composite
+     * extension was changed from "Composite" to "COMPOSITE". As of
+     * that release extension names are case-sensitive so we must 
+     * ensure the correct case is used.
+     */
+    if (major == 1 && minor >= 20) {
+        *compositeExtensionName = "COMPOSITE";
+    } else {
+        *compositeExtensionName = "Composite";
+    }
+
     return TRUE;
 
 } /* get_xserver_information() */
@@ -1428,13 +1420,13 @@ static int get_xserver_information(const char *versionString,
 void xconfigGetXServerInUse(GenerateOptions *gop)
 {
     FILE *stream = NULL;
-    int xserver = -1;
-    int isXorg;
-    int dummy, len, found;
+    int len, found;
     char *cmd, *ptr, *ret;
 
     gop->supports_extension_section = FALSE;
     gop->autoloads_glx = FALSE;
+    gop->xinerama_plus_composite_works = FALSE;
+    gop->compositeExtensionName = NULL;
 
     /* run `X -version` with a PATH that hopefully includes the X binary */
 
@@ -1461,18 +1453,12 @@ void xconfigGetXServerInUse(GenerateOptions *gop)
          */
 
         found = get_xserver_information(buf,
-                                        &isXorg,
-                                        &dummy, /* isModular */
                                         &gop->autoloads_glx,
-                                        &gop->supports_extension_section);
+                                        &gop->supports_extension_section,
+                                        &gop->xinerama_plus_composite_works,
+                                        &gop->compositeExtensionName);
 
-        if (found) {
-            if (isXorg) {
-                xserver = X_IS_XORG;
-            } else {
-                xserver = X_IS_XF86;
-            }
-        } else {
+        if (!found) {
             xconfigErrorMsg(WarnMsg, "Unable to parse X.Org version string.");
         }
     }
@@ -1480,20 +1466,6 @@ void xconfigGetXServerInUse(GenerateOptions *gop)
     pclose(stream);
     free(cmd);
 
-    if (xserver == -1) {
-        char *xorgpath;
-
-        xorgpath = xconfigStrcat(gop->x_project_root, "/bin/Xorg", NULL);
-        if (access(xorgpath, F_OK)==0) {
-            xserver = X_IS_XORG;
-        } else {
-            xserver = X_IS_XF86;
-        }
-        free(xorgpath);
-    }
-
-    gop->xserver=xserver;
-
 } /* xconfigGetXServerInUse() */
 
 
@@ -1510,7 +1482,6 @@ void xconfigGenerateLoadDefaultOptions(GenerateOptions *gop)
     gop->x_project_root = xconfigGetDefaultProjectRoot();
 
     /* XXX What to default the following to?
-       gop->xserver
        gop->keyboard
        gop->mouse
        gop->keyboard_driver
