@@ -161,25 +161,35 @@ static int queryBaseInfo(CtkVDPAU *ctk_vdpau, VdpDevice device,
                          VdpGetProcAddress *getProcAddress)
 {
     static const Desc decoder_list[] = {
-        {"MPEG1",              VDP_DECODER_PROFILE_MPEG1, 0x01},
-        {"MPEG2",       VDP_DECODER_PROFILE_MPEG2_SIMPLE, 0x02},
-        {"MPEG2",         VDP_DECODER_PROFILE_MPEG2_MAIN, 0x02},
-        {"H264",       VDP_DECODER_PROFILE_H264_BASELINE, 0x04},
-        {"H264",           VDP_DECODER_PROFILE_H264_MAIN, 0x04},
-        {"H264",           VDP_DECODER_PROFILE_H264_HIGH, 0x04},
-        {"VC1",           VDP_DECODER_PROFILE_VC1_SIMPLE, 0x08},
-        {"VC1"  ,           VDP_DECODER_PROFILE_VC1_MAIN, 0x08},
-        {"VC1",         VDP_DECODER_PROFILE_VC1_ADVANCED, 0x08},
-        {"MPEG4",     VDP_DECODER_PROFILE_MPEG4_PART2_SP, 0x10},
-        {"MPEG4",    VDP_DECODER_PROFILE_MPEG4_PART2_ASP, 0x10},
-        {"DIVX4",      VDP_DECODER_PROFILE_DIVX4_QMOBILE, 0x20},
-        {"DIVX4",       VDP_DECODER_PROFILE_DIVX4_MOBILE, 0x20},
-        {"DIVX4", VDP_DECODER_PROFILE_DIVX4_HOME_THEATER, 0x20},
-        {"DIVX4",     VDP_DECODER_PROFILE_DIVX4_HD_1080P, 0x20},
-        {"DIVX5",      VDP_DECODER_PROFILE_DIVX5_QMOBILE, 0x40},
-        {"DIVX5",       VDP_DECODER_PROFILE_DIVX5_MOBILE, 0x40},
-        {"DIVX5", VDP_DECODER_PROFILE_DIVX5_HOME_THEATER, 0x40},
-        {"DIVX5",     VDP_DECODER_PROFILE_DIVX5_HD_1080P, 0x40},
+        {"MPEG1",                    VDP_DECODER_PROFILE_MPEG1, 0x01},
+        {"MPEG2",             VDP_DECODER_PROFILE_MPEG2_SIMPLE, 0x02},
+        {"MPEG2",               VDP_DECODER_PROFILE_MPEG2_MAIN, 0x02},
+        {"H264",             VDP_DECODER_PROFILE_H264_BASELINE, 0x04},
+        {"H264",                 VDP_DECODER_PROFILE_H264_MAIN, 0x04},
+        {"H264",                 VDP_DECODER_PROFILE_H264_HIGH, 0x04},
+        {"H264", VDP_DECODER_PROFILE_H264_CONSTRAINED_BASELINE, 0x04},
+        {"H264",             VDP_DECODER_PROFILE_H264_EXTENDED, 0x04},
+        {"H264",     VDP_DECODER_PROFILE_H264_PROGRESSIVE_HIGH, 0x04},
+        {"H264",     VDP_DECODER_PROFILE_H264_CONSTRAINED_HIGH, 0x04},
+        {"H264",  VDP_DECODER_PROFILE_H264_HIGH_444_PREDICTIVE, 0x04},
+        {"VC1",                 VDP_DECODER_PROFILE_VC1_SIMPLE, 0x08},
+        {"VC1"  ,                 VDP_DECODER_PROFILE_VC1_MAIN, 0x08},
+        {"VC1",               VDP_DECODER_PROFILE_VC1_ADVANCED, 0x08},
+        {"MPEG4",           VDP_DECODER_PROFILE_MPEG4_PART2_SP, 0x10},
+        {"MPEG4",          VDP_DECODER_PROFILE_MPEG4_PART2_ASP, 0x10},
+        {"DIVX4",            VDP_DECODER_PROFILE_DIVX4_QMOBILE, 0x20},
+        {"DIVX4",             VDP_DECODER_PROFILE_DIVX4_MOBILE, 0x20},
+        {"DIVX4",       VDP_DECODER_PROFILE_DIVX4_HOME_THEATER, 0x20},
+        {"DIVX4",           VDP_DECODER_PROFILE_DIVX4_HD_1080P, 0x20},
+        {"DIVX5",            VDP_DECODER_PROFILE_DIVX5_QMOBILE, 0x40},
+        {"DIVX5",             VDP_DECODER_PROFILE_DIVX5_MOBILE, 0x40},
+        {"DIVX5",       VDP_DECODER_PROFILE_DIVX5_HOME_THEATER, 0x40},
+        {"DIVX5",           VDP_DECODER_PROFILE_DIVX5_HD_1080P, 0x40},
+        {"HEVC",                 VDP_DECODER_PROFILE_HEVC_MAIN, 0x80},
+        {"HEVC",              VDP_DECODER_PROFILE_HEVC_MAIN_10, 0x80},
+        {"HEVC",           VDP_DECODER_PROFILE_HEVC_MAIN_STILL, 0x80},
+        {"HEVC",              VDP_DECODER_PROFILE_HEVC_MAIN_12, 0x80},
+        {"HEVC",             VDP_DECODER_PROFILE_HEVC_MAIN_444, 0x80},
     };
     const size_t decoder_list_count = sizeof(decoder_list)/sizeof(Desc);
 
@@ -274,6 +284,12 @@ static const Desc ycbcr_types[] = {
     {"YUYV", VDP_YCBCR_FORMAT_YUYV, 0},
     {"Y8U8V8A8", VDP_YCBCR_FORMAT_Y8U8V8A8, 0},
     {"V8U8Y8A8", VDP_YCBCR_FORMAT_V8U8Y8A8, 0},
+#ifdef VDP_YCBCR_FORMAT_Y_UV_444
+    {"Y_UV_444",  VDP_YCBCR_FORMAT_Y_UV_444,  0},
+    {"Y_U_V_444", VDP_YCBCR_FORMAT_Y_U_V_444, 0},
+#else
+#warning "Update libvdpau to version 1.2"
+#endif
 };
 static const size_t ycbcr_type_count = sizeof(ycbcr_types)/sizeof(Desc);
 
@@ -441,7 +457,7 @@ static int queryVideoSurface(CtkVDPAU *ctk_vdpau, VdpDevice device,
                     str1 = g_string_append(str1, s);
                 }
             }
-            label = gtk_label_new(g_strdup_printf(str1->str));
+            label = gtk_label_new(g_strdup_printf("%s", str1->str));
             gtk_label_set_selectable(GTK_LABEL(label), TRUE);
             gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
             gtk_table_attach(GTK_TABLE(table), label, 3, 4, count+1, count+2,
@@ -475,6 +491,15 @@ static int queryDecoderCaps(CtkVDPAU *ctk_vdpau, VdpDevice device,
         {"H264 Baseline",      VDP_DECODER_PROFILE_H264_BASELINE,      0},
         {"H264 Main",          VDP_DECODER_PROFILE_H264_MAIN,          0},
         {"H264 High",          VDP_DECODER_PROFILE_H264_HIGH,          0},
+        {"H264 Constrained Baseline",
+                               VDP_DECODER_PROFILE_H264_CONSTRAINED_BASELINE, 0},
+        {"H264 Extended",      VDP_DECODER_PROFILE_H264_EXTENDED,      0},
+        {"H264 Progressive High",
+                               VDP_DECODER_PROFILE_H264_PROGRESSIVE_HIGH, 0},
+        {"H264 Constrained High",
+                               VDP_DECODER_PROFILE_H264_CONSTRAINED_HIGH, 0},
+        {"H264 High 4:4:4 Predictive",
+                               VDP_DECODER_PROFILE_H264_HIGH_444_PREDICTIVE, 0},
         {"VC1 Simple",         VDP_DECODER_PROFILE_VC1_SIMPLE,         0},
         {"VC1 Main",           VDP_DECODER_PROFILE_VC1_MAIN,           0},
         {"VC1 Advanced",       VDP_DECODER_PROFILE_VC1_ADVANCED,       0},
@@ -490,6 +515,11 @@ static int queryDecoderCaps(CtkVDPAU *ctk_vdpau, VdpDevice device,
         {"DIVX5 Mobile",       VDP_DECODER_PROFILE_DIVX5_MOBILE,       0},
         {"DIVX5 Home Theater", VDP_DECODER_PROFILE_DIVX5_HOME_THEATER, 0},
         {"DIVX5 HD 1080P",     VDP_DECODER_PROFILE_DIVX5_HD_1080P,     0},
+        {"HEVC Main",          VDP_DECODER_PROFILE_HEVC_MAIN,          0},
+        {"HEVC Main 10",       VDP_DECODER_PROFILE_HEVC_MAIN_10,       0},
+        {"HEVC Main Still Picture", VDP_DECODER_PROFILE_HEVC_MAIN_STILL, 0},
+        {"HEVC Main 12",       VDP_DECODER_PROFILE_HEVC_MAIN_12,       0},
+        {"HEVC Main 4:4:4",    VDP_DECODER_PROFILE_HEVC_MAIN_444,      0},
     };
     const size_t decoder_profile_count = sizeof(decoder_profiles)/sizeof(Desc);
 
@@ -620,8 +650,8 @@ static int queryDecoderCaps(CtkVDPAU *ctk_vdpau, VdpDevice device,
             gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
             gtk_table_attach(GTK_TABLE(table), label, 4, 5, count+3, count+4,
                              GTK_FILL, GTK_FILL | GTK_EXPAND, 5, 0);
+            count++;
         }
-        count++;
     }
     return 0;
 } /* queryDecoderCaps() */
@@ -769,7 +799,7 @@ static int queryOutputSurface(CtkVDPAU *ctk_vdpau, VdpDevice device,
                     str1 = g_string_append(str1, s);
                 }
             }
-            label = gtk_label_new(g_strdup_printf(str1->str));
+            label = gtk_label_new(g_strdup_printf("%s", str1->str));
             gtk_label_set_selectable(GTK_LABEL(label), TRUE);
             gtk_misc_set_alignment(GTK_MISC(label), 0.0f, 0.5f);
             gtk_table_attach(GTK_TABLE(table), label, 4, 5, count+1, count+2,
@@ -1344,8 +1374,7 @@ GType ctk_vdpau_get_type(void)
 
 
 
-GtkWidget* ctk_vdpau_new(NvCtrlAttributeHandle *handle,
-                         CtkConfig *ctk_config,
+GtkWidget* ctk_vdpau_new(CtrlTarget *ctrl_target, CtkConfig *ctk_config,
                          CtkEvent *ctk_event)
 {
     GObject *object;
@@ -1366,16 +1395,13 @@ GtkWidget* ctk_vdpau_new(NvCtrlAttributeHandle *handle,
 
     /* make sure we have a handle */
 
-    g_return_val_if_fail(handle != NULL, NULL);
+    g_return_val_if_fail((ctrl_target != NULL) &&
+                         (ctrl_target->h != NULL), NULL);
 
     /* Create the ctk vdpau object */
     object = g_object_new(CTK_TYPE_VDPAU, NULL);
     ctk_vdpau = CTK_VDPAU(object);
 
-
-    /* Cache the attribute handle */
-    ctk_vdpau->handle = handle;
-
     /* Set container properties of the object */
     ctk_vdpau->ctk_config = ctk_config;
     gtk_box_set_spacing(GTK_BOX(ctk_vdpau), 10);
@@ -1397,8 +1423,8 @@ GtkWidget* ctk_vdpau_new(NvCtrlAttributeHandle *handle,
 
 
     /* get device and ProcAddress */
-    ret = VDPAUDeviceCreateX11(NvCtrlGetDisplayPtr(handle),
-                               NvCtrlGetScreen(handle),
+    ret = VDPAUDeviceCreateX11(NvCtrlGetDisplayPtr(ctrl_target),
+                               NvCtrlGetScreen(ctrl_target),
                                &device, &getProcAddress);
 
     if ((ret != VDP_STATUS_OK) || !device || !getProcAddress) {
@@ -1494,43 +1520,43 @@ GtkTextBuffer *ctk_vdpau_create_help(GtkTextTagTable *table,
     gtk_text_buffer_get_iter_at_offset(b, &i, 0);
 
     ctk_help_title(b, &i, "VDPAU Information Help");
-    ctk_help_para(b, &i, __vdpau_information_label_help);
+    ctk_help_para(b, &i, "%s", __vdpau_information_label_help);
 
     ctk_help_heading(b, &i, "Base Information");
-    ctk_help_para(b, &i, __base_information_help);
+    ctk_help_para(b, &i, "%s", __base_information_help);
 
     ctk_help_heading(b, &i, "API Version");
-    ctk_help_para(b, &i, __vdpau_api_version_help);
+    ctk_help_para(b, &i, "%s", __vdpau_api_version_help);
 
     ctk_help_heading(b, &i, "Supported Codecs");
-    ctk_help_para(b, &i, __supported_codecs_help);
+    ctk_help_para(b, &i, "%s", __supported_codecs_help);
 
     ctk_help_heading(b, &i, "Surface Limits");
-    ctk_help_para(b, &i, __surface_limits_help);
+    ctk_help_para(b, &i, "%s", __surface_limits_help);
 
     ctk_help_heading(b, &i, "Video Surface");
-    ctk_help_para(b, &i, __video_surface_help);
+    ctk_help_para(b, &i, "%s", __video_surface_help);
 
     ctk_help_heading(b, &i, "Output Surface");
-    ctk_help_para(b, &i, __ouput_surface_help);
+    ctk_help_para(b, &i, "%s", __ouput_surface_help);
 
     ctk_help_heading(b, &i, "Bitmap Surface");
-    ctk_help_para(b, &i, __bitmap_surface_help);
+    ctk_help_para(b, &i, "%s", __bitmap_surface_help);
 
     ctk_help_heading(b, &i, "Decoder Limits");
-    ctk_help_para(b, &i, __decoder_limits_help);
+    ctk_help_para(b, &i, "%s", __decoder_limits_help);
 
     ctk_help_heading(b, &i, "Video Mixer");
-    ctk_help_para(b, &i, __video_mixer_help);
+    ctk_help_para(b, &i, "%s", __video_mixer_help);
 
     ctk_help_term(b, &i, "Feature");
-    ctk_help_para(b, &i, __video_mixer_feature_help);
+    ctk_help_para(b, &i, "%s", __video_mixer_feature_help);
 
     ctk_help_term(b, &i, "Parameter");
-    ctk_help_para(b, &i, __video_mixer_parameter_help);
+    ctk_help_para(b, &i, "%s", __video_mixer_parameter_help);
 
     ctk_help_term(b, &i, "Attribute");
-    ctk_help_para(b, &i, __video_mixer_attribute_help);
+    ctk_help_para(b, &i, "%s", __video_mixer_attribute_help);
 
     ctk_help_finish(b);
     return b;
